package com.ruoyi.web.controller.platform;


import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.PageInfo;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.BaseParam;
import com.ruoyi.system.domain.BasicLibrary;
import com.ruoyi.system.service.BasicLibraryService;
import io.swagger.annotations.ApiOperation;
import org.apache.poi.ss.formula.functions.T;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * 基础库管理Controller
 * 
 * @author liming
 * @date 2023-07-12
 */
@RestController
@RequestMapping("/platform/v1/base")
public class BasicLibraryController extends BaseController {
    @Autowired
    private BasicLibraryService basicLibraryService;

    /**
     * 查询基础库列表
     */
    @ApiOperation("查询基础库管理列表")
//    @PreAuthorize("@ss.hasPermi('platform:base:list')")
    @PostMapping("/list")
    public R<PageInfo<BasicLibrary>> list(@RequestBody BaseParam param) {
        IPage<BasicLibrary> basicLibraryIPage = basicLibraryService.page(new Page<BasicLibrary>().setCurrent(param.getCurrent()).setSize(param.getSize()),
                new LambdaQueryWrapper<BasicLibrary>().like(param.getName()!=null,BasicLibrary::getName,param.getName())
                        .eq(BasicLibrary::getDelFlag,0));
        PageInfo<BasicLibrary> pageInfo = new PageInfo<>();
        pageInfo.setRecords(basicLibraryIPage.getRecords());
        pageInfo.setSize(basicLibraryIPage.getSize());
        pageInfo.setCurrent(basicLibraryIPage.getCurrent());
        pageInfo.setTotal(basicLibraryIPage.getTotal());
        return R.ok(pageInfo);
    }


    /**
     * 查询基础库列表
     */
    @ApiOperation("查询基础库管理列表")
//    @PreAuthorize("@ss.hasPermi('platform:base:list')")
    @PostMapping("/allList")
    public R<List<BasicLibrary>> getAllList() {
        List<BasicLibrary> basicLibraryList = basicLibraryService.list(new LambdaQueryWrapper<BasicLibrary>().eq(BasicLibrary::getDelFlag,0));
        return R.ok(basicLibraryList);
    }

    
    /**
     * 获取基础库详细信息
     */
//    @PreAuthorize("@ss.hasPermi('platform:base:query')")
    @PostMapping(value = "/getInfo")
    public R<BasicLibrary> getInfo(@RequestBody BaseParam param){

        return R.ok( basicLibraryService.getOne(new LambdaQueryWrapper<BasicLibrary>().eq(BasicLibrary::getId, param.getId())
                .eq(BasicLibrary::getDelFlag, "0"), false));
    }

    /**
     * 新增修改基础库
     */
//    @PreAuthorize("@ss.hasPermi('platform:base:add')")
    @Log(title = "基础库管理", businessType = BusinessType.INSERT)
    @PostMapping("addOrUpdate")
    public R<Boolean> add(@RequestBody BasicLibrary param) {
        //参数校验
//        String[] bootCode = param.getBootCode().split(",");
//        if (bootCode.length != 2){
//            return R.fail("引导码参数格式有误");
//        }
//        if (param.getBootCodeSend() < 0){
//            return R.fail("引导码发送次数参数有误");
//        }
//        String[] synchronizeCode = param.getSynchronizeCode().split(",");
//        if (synchronizeCode.length != 2){
//            return R.fail("同步码参数格式有误");
//        }
//        if (param.getSynchronizeCodeSend() < 0){
//            return R.fail("同步码发送次数参数有误");
//        }

//        String[] dateCode = param.getDateCode().split(",");
//        if (dateCode.length % 2 != 0){
//            return R.fail("数据码参数有误");
//        }
//        if (StringUtils.isEmpty(param.getDateCode())){
//            return R.fail("数据码参数不能为空");
//        }
//
//        String[] dateBinary0 = param.getDateBinary0().split(",");
//        if (dateBinary0.length != 2){
//            return R.fail("数据码二进制0参数格式有误");
//        }
//        String[] dateBinary1 = param.getDateBinary1().split(",");
//        if (dateBinary1.length != 2){
//            return R.fail("数据码二进制1参数格式有误");
//        }
//
//        String[] overCode = param.getOverCode().split(",");
//        if (overCode.length != 2){
//            return R.fail("结束码参数有误");
//        }
        if (param.getId() != null) {
            param.setUpdateTime(DateUtils.getNowDate());
        }else {
            param.setCreateTime(DateUtils.getNowDate());
        }
        return R.ok(basicLibraryService.saveOrUpdate(param));
    }


    /**
     * 删除红外遥控基础库
     */
//    @PreAuthorize("@ss.hasPermi('platform:base:remove')")
    @Log(title = "基础库管理", businessType = BusinessType.DELETE)
	@PostMapping("/delete")
    public R<T> remove(@RequestBody BaseParam param) {
        boolean flat = basicLibraryService.removeById(param.getId());
        if (!flat){
            return R.fail("删除失败");
        }
        return R.ok();
    }
}
